const { colors, typography, spacing, shadows, radii, transition } = require('../../src');
const { alertVariants } = require('./components/alert');
const { badgeVariants } = require('./components/badge');
const { buttonVariants, buttonIconVariants } = require('./components/button');
const { cardStyles, cardVariants } = require('./components/card');
const { checkboxStyles } = require('./components/checkbox');
const { dividerStyles } = require('./components/divider');
const { inputStyles } = require('./components/input');
const { logoVariants } = require('./components/logo');
const { radioStyles } = require('./components/radio');
const { selectStyles } = require('./components/select');
const { switchStyles } = require('./components/switch');
const { tagStyles } = require('./components/tag');
const { tooltipStyles } = require('./components/tooltip');
const { modalStyles } = require('./components/modal');
const { progressStyles } = require('./components/progress');
const { popoverStyles } = require('./components/popover');
const { textStyles } = require('./components/text');
const { boneStyles } = require('./components/bone');
const { groupStyles } = require('./components/group');
const { wordmarkStyles } = require('./components/wordmark');
const { tableStyles } = require('./components/table');
const { sidebarStyles } = require('./components/sidebar');
const { npsStyles } = require('./components/nps');

const colorsMap = colors.colorsMap;

// Adding aliases for easy consumption on the consumer side
colorsMap.primary = colorsMap.green;
colorsMap.secondary = colorsMap.blue;
colorsMap.danger = colorsMap.maple;
colorsMap.warning = colorsMap.orange;
colorsMap.white = colorsMap.snow;
colorsMap.textBody = colorsMap.gray;
colorsMap.textHeading = colorsMap.night;
colorsMap.textDimmed = colorsMap['gray-300'];
colorsMap.disabled = colorsMap['snow-300'];
colorsMap.dimmed = colorsMap['snow-200'];

const theme = {
  breakpoints: ['601px', '1024px'],
  colors: colorsMap,
  fontFamily: typography.typeface,
  space: Object.values(spacing.scale),
  lineHeights: Object.values(spacing.scale),
  fontSizes: { ...typography.fontSizes, ...typography.fontSizeAliases },
  fontWeights: typography.weights,
  letterSpacings: [...Object.values(typography.letterSpacings)],
  shadows: Object.values(shadows.outer),
  innerShadows: Object.values(shadows.inner),
  innerShadowsN: Object.values(shadows.innerN),
  borderShadows: Object.values(shadows.border),
  radii: radii.values,
  transition: transition.durations,
  alertVariants,
  badgeVariants,
  buttonVariants,
  buttonIconVariants,
  cardStyles,
  cardVariants,
  checkboxStyles,
  dividerStyles,
  inputStyles,
  logoVariants,
  radioStyles,
  selectStyles,
  switchStyles,
  tagStyles,
  tooltipStyles,
  modalStyles,
  progressStyles,
  popoverStyles,
  textStyles,
  boneStyles,
  groupStyles,
  wordmarkStyles,
  tableStyles,
  sidebarStyles,
  npsStyles,
};

module.exports = JSON.stringify(theme);
